@@ -531,9 +531,9 @@ class ZindiTurtleRecall(Downloader):
 
 
 class Segmented(Downloader):
-    warning = "You are trying to download a segmented dataset. \
-                It is already included in its non-segmented version download. \
-                Skipping."
+    warning = '''You are trying to download a segmented dataset.
+        It is already included in its non-segmented version download.
+        Skipping.'''
     
     def get_data(self, root, name=None):
         print(self.warning)
